"""Created on Nov 02 21:24:07 2024"""

__version__ = "1.2.0"
__author__ = "Iqra Siddique"
__email__ = "iqra.siddique07@gmail.com"
__license__ = "MIT"
__copyright__ = "2024, Iqra Siddique"
__url__ = "https://github.com/iqraSiddique42/EnergyCalibrationPy"
__description__ = "A library to calibrate energy spectrum - part of my PhD work."
